@@ -10,7 +10,7 @@ from .utils import GtkTemplate, stateful_property
 
 from copy import deepcopy
 from functools import wraps
-from gi.repository import GdkPixbuf, Gio, GLib, Gtk, GObject
+from gi.repository import GdkPixbuf, Gdk, Gio, GLib, Gtk, GObject
 import os
 import shutil
 import sys
@@ -32,14 +32,14 @@ GObject.threads_init()
 def hide_on_delete(window, *args):
     '''
     Warpper for Gtk.Widget.hide_on_delete, but allow superfluous arguments.
-    Used for singal callback.
+    Used for signal callback.
     '''
     return Gtk.Widget.hide_on_delete(window)
 
 
 def reset_dialog(dialog, *args):
     '''
-    Select cancel button as default when reshow the dialog. Used for singal
+    Select cancel button as default when reshow the dialog. Used for signal
     callback.
     '''
     btn_cancel = \
@@ -364,7 +364,8 @@ class MainWindow(object):
             'main_window', 'main_accelgroup',
             'pending_box', 'groups_tv',
             'group_find_btn', 'group_find_entry', 'groups_tv_filter',
-            'alternative_label', 'link_label', 'description_label',
+            'group_icon', 'alternative_label',
+            'link_label', 'description_label',
             'status_switch', 'options_tv', 'options_column_package',
             'options_menu',
             # dialogs and messages
@@ -517,8 +518,9 @@ class MainWindow(object):
             model = self.results_tv.get_model()
             model.clear()
             for cmd, result in zip_longest(friendlize(diff_cmds), results):
-                it = model.append(
-                    None, (STATUS_ICONS[result.returncode != 0 if result else 2], cmd[0]))
+                it = model.append(None, (
+                    STATUS_ICONS[result.returncode != 0 if result else 2],
+                    cmd[0]))
                 for info in cmd[1:]:
                     model.append(it, (
                         None, '    ' + info))
@@ -590,6 +592,11 @@ class MainWindow(object):
         self.group_cleaning = False
         self.click_group()
 
+    def on_group_find_entry_key_release_event(self, widget, event):
+        if event.keyval == Gdk.KEY_Escape:
+            self.group_find_btn.set_active(False)
+            self.find_group(None, None)
+
     def group_filter(self, model, iter, data):
         return self.group_filter_pattern in model[iter][0]
 
@@ -686,10 +693,12 @@ class MainWindow(object):
             return
 
         # set the name of the alternative to the information area
-        name, description = altname_description(self.group.name)
+        name, description, icon = altname_description(self.group.name)
         self.alternative_label.set_text(name)
         self.link_label.set_text(self.group.link)
         self.description_label.set_text(description)
+        self.group_icon.set_from_icon_name(
+            icon, self.group_icon.get_icon_name()[1])
         self.status_switch.set_active(self.group.status)
 
         # set columns
